Class: RailsBestPractices::Lexicals::RemoveTrailingWhitespaceCheck

Inherits:
Core::Check
  • Object
show all
Defined in:
lib/rails_best_practices/lexicals/remove_trailing_whitespace_check.rb

Overview

Make sure there are no trailing whitespace in codes.

See the best practice details here rails-bestpractices.com/posts/2010/12/02/remove-trailing-whitespace/

Constant Summary

Constants inherited from Core::Check

Core::Check::ALL_FILES, Core::Check::CAPFILE, Core::Check::CONFIG_FILES, Core::Check::CONTROLLER_FILES, Core::Check::DEPLOY_FILES, Core::Check::GEMFILE_LOCK, Core::Check::HELPER_FILES, Core::Check::INITIALIZER_FILES, Core::Check::MAILER_FILES, Core::Check::MIGRATION_FILES, Core::Check::MODEL_FILES, Core::Check::PARTIAL_VIEW_FILES, Core::Check::ROUTE_FILES, Core::Check::SCHEMA_FILE, Core::Check::SKIP_FILES, Core::Check::VIEW_FILES

Instance Method Summary collapse

Methods inherited from Core::Check

#add_error, debug, debug?, #errors, #initialize, #is_ignored?, #is_interesting_file?, #method_missing, #parse_file?, #regex_ignored_files, #url, url

Constructor Details

This class inherits a constructor from RailsBestPractices::Core::Check

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class RailsBestPractices::Core::Check

Instance Method Details

#check(filename, content) ⇒ Object

check if the content of file contain a trailing whitespace.

Parameters:

  • filename (String)

    name of the file

  • content (String)

    content of the file



16
17
18
19
20
21
# File 'lib/rails_best_practices/lexicals/remove_trailing_whitespace_check.rb', line 16

def check(filename, content)
  if content =~ / +\n/m
    line_no = $`.count("\n") + 1
    add_error('remove trailing whitespace', filename, line_no)
  end
end