Class: RailsBestPractices::Reviews::MoveCodeIntoModelReview

Inherits:
Review
  • Object
show all
Defined in:
lib/rails_best_practices/reviews/move_code_into_model_review.rb

Overview

Review a view file to make sure there is no complex logic call for model.

See the best practice details here rails-bestpractices.com/posts/2010/07/24/move-code-into-model/

Implementation:

Review process:

check if, unless, elsif there are multiple method calls or attribute assignments apply to one receiver,
and the receiver is a variable, then they should be moved into model.

Constant Summary

Constants inherited from Core::Check

Core::Check::ALL_FILES, Core::Check::CAPFILE, Core::Check::CONFIG_FILES, Core::Check::CONTROLLER_FILES, Core::Check::DEPLOY_FILES, Core::Check::GEMFILE_LOCK, Core::Check::HELPER_FILES, Core::Check::INITIALIZER_FILES, Core::Check::MAILER_FILES, Core::Check::MIGRATION_FILES, Core::Check::MODEL_FILES, Core::Check::PARTIAL_VIEW_FILES, Core::Check::ROUTE_FILES, Core::Check::SCHEMA_FILE, Core::Check::SKIP_FILES, Core::Check::VIEW_FILES

Instance Method Summary collapse

Methods inherited from Review

#model_associations, #model_attributes, #models, #remember_variable_use_count, #reset_variable_use_count, #variable, #variable_use_count

Methods inherited from Core::Check

#add_error, debug, debug?, #errors, #is_ignored?, #is_interesting_file?, #method_missing, #parse_file?, #regex_ignored_files, #url, url

Constructor Details

#initialize(options = {}) ⇒ MoveCodeIntoModelReview

Returns a new instance of MoveCodeIntoModelReview.



19
20
21
22
# File 'lib/rails_best_practices/reviews/move_code_into_model_review.rb', line 19

def initialize(options = {})
  super(options)
  @use_count = options['use_count'] || 2
end

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class RailsBestPractices::Core::Check