Class: RailsBestPractices::Reviews::AddModelVirtualAttributeReview
- Inherits:
-
Review
- Object
- CodeAnalyzer::Checker
- Core::Check
- Review
- RailsBestPractices::Reviews::AddModelVirtualAttributeReview
- Defined in:
- lib/rails_best_practices/reviews/add_model_virtual_attribute_review.rb
Overview
Make sure to add a model virual attribute to simplify model creation.
See the best practice details here rails-bestpractices.com/posts/2010/07/21/add-model-virtual-attribute/
Implementation:
Review process:
check method define nodes in all controller files,
if there are more than one [] method calls with the same receiver and arguments,
but assigned to one model's different attribute.
and after these method calls, there is a save method call for that model,
then the model needs to add a virtual attribute.
Constant Summary
Constants inherited from Core::Check
Core::Check::ALL_FILES, Core::Check::CAPFILE, Core::Check::CONFIG_FILES, Core::Check::CONTROLLER_FILES, Core::Check::DEPLOY_FILES, Core::Check::GEMFILE_LOCK, Core::Check::HELPER_FILES, Core::Check::INITIALIZER_FILES, Core::Check::MAILER_FILES, Core::Check::MIGRATION_FILES, Core::Check::MODEL_FILES, Core::Check::PARTIAL_VIEW_FILES, Core::Check::ROUTE_FILES, Core::Check::SCHEMA_FILE, Core::Check::SKIP_FILES, Core::Check::VIEW_FILES
Method Summary
Methods inherited from Review
#model_associations, #model_attributes, #models, #remember_variable_use_count, #reset_variable_use_count, #variable, #variable_use_count
Methods inherited from Core::Check
#add_error, debug, debug?, #errors, #initialize, #is_ignored?, #is_interesting_file?, #method_missing, #parse_file?, #regex_ignored_files, #url, url
Constructor Details
This class inherits a constructor from RailsBestPractices::Core::Check
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class RailsBestPractices::Core::Check