Class: RailsBestPractices::Reviews::MoveCodeIntoHelperReview
- Inherits:
-
Review
- Object
- CodeAnalyzer::Checker
- Core::Check
- Review
- RailsBestPractices::Reviews::MoveCodeIntoHelperReview
- Defined in:
- lib/rails_best_practices/reviews/move_code_into_helper_review.rb
Overview
Review a view file to make sure there is no complex options_for_select message call.
See the best practice details here rails-bestpractices.com/posts/2010/07/24/move-code-into-helper/
TODO: we need a better soluation, any suggestion?
Implementation:
Review process:
check al method method_add_arg nodes to see if there is a complex options_for_select helper.
if the message of the method_add_arg node is options_for_select,
and the first argument of the method_add_arg node is array,
and the size of the array is greater than array_count defined,
then the options_for_select method should be moved into helper.
Constant Summary
Constants inherited from Core::Check
Core::Check::ALL_FILES, Core::Check::CAPFILE, Core::Check::CONFIG_FILES, Core::Check::CONTROLLER_FILES, Core::Check::DEPLOY_FILES, Core::Check::GEMFILE_LOCK, Core::Check::HELPER_FILES, Core::Check::INITIALIZER_FILES, Core::Check::MAILER_FILES, Core::Check::MIGRATION_FILES, Core::Check::MODEL_FILES, Core::Check::PARTIAL_VIEW_FILES, Core::Check::ROUTE_FILES, Core::Check::SCHEMA_FILE, Core::Check::SKIP_FILES, Core::Check::VIEW_FILES
Instance Method Summary collapse
-
#initialize(options = {}) ⇒ MoveCodeIntoHelperReview
constructor
A new instance of MoveCodeIntoHelperReview.
Methods inherited from Review
#model_associations, #model_attributes, #models, #remember_variable_use_count, #reset_variable_use_count, #variable, #variable_use_count
Methods inherited from Core::Check
#add_error, debug, debug?, #errors, #is_ignored?, #is_interesting_file?, #method_missing, #parse_file?, #regex_ignored_files, #url, url
Constructor Details
#initialize(options = {}) ⇒ MoveCodeIntoHelperReview
Returns a new instance of MoveCodeIntoHelperReview.
25 26 27 28 |
# File 'lib/rails_best_practices/reviews/move_code_into_helper_review.rb', line 25 def initialize( = {}) super() @array_count = ['array_count'] || 3 end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class RailsBestPractices::Core::Check