Class: RailsBestPractices::Reviews::MoveFinderToNamedScopeReview
- Inherits:
-
Review
- Object
- CodeAnalyzer::Checker
- Core::Check
- Review
- RailsBestPractices::Reviews::MoveFinderToNamedScopeReview
- Defined in:
- lib/rails_best_practices/reviews/move_finder_to_named_scope_review.rb
Overview
Review a controller file to make sure there are no complex finder.
See the best practice details here rails-bestpractices.com/posts/2010/07/14/move-finder-to-named_scope/
Implementation:
Review process:
check all method method_add_arg nodes in controller files.
if there is any call node with message find, all, first or last,
and it has a hash argument,
then it is a complex finder, and should be moved to model's named scope.
Constant Summary collapse
- FINDERS =
%w[find all first last].freeze
Constants inherited from Core::Check
Core::Check::ALL_FILES, Core::Check::CAPFILE, Core::Check::CONFIG_FILES, Core::Check::CONTROLLER_FILES, Core::Check::DEPLOY_FILES, Core::Check::GEMFILE_LOCK, Core::Check::HELPER_FILES, Core::Check::INITIALIZER_FILES, Core::Check::MAILER_FILES, Core::Check::MIGRATION_FILES, Core::Check::MODEL_FILES, Core::Check::PARTIAL_VIEW_FILES, Core::Check::ROUTE_FILES, Core::Check::SCHEMA_FILE, Core::Check::SKIP_FILES, Core::Check::VIEW_FILES
Method Summary
Methods inherited from Review
#model_associations, #model_attributes, #models, #remember_variable_use_count, #reset_variable_use_count, #variable, #variable_use_count
Methods inherited from Core::Check
#add_error, debug, debug?, #errors, #initialize, #is_ignored?, #is_interesting_file?, #method_missing, #parse_file?, #regex_ignored_files, #url, url
Constructor Details
This class inherits a constructor from RailsBestPractices::Core::Check
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class RailsBestPractices::Core::Check