Class: RailsBestPractices::Reviews::MoveModelLogicIntoModelReview
- Inherits:
-
Review
- Object
- CodeAnalyzer::Checker
- Core::Check
- Review
- RailsBestPractices::Reviews::MoveModelLogicIntoModelReview
- Defined in:
- lib/rails_best_practices/reviews/move_model_logic_into_model_review.rb
Overview
Review a controller file to make sure that complex model logic should not exist in controller, should be moved into a model.
See the best practice details here rails-bestpractices.com/posts/2010/07/21/move-model-logic-into-the-model/
Implementation:
Review process:
check all method defines in the controller files,
if there are multiple method calls apply to one receiver,
and the receiver is a variable,
then they are complex model logic, and they should be moved into model.
Constant Summary
Constants inherited from Core::Check
Core::Check::ALL_FILES, Core::Check::CAPFILE, Core::Check::CONFIG_FILES, Core::Check::CONTROLLER_FILES, Core::Check::DEPLOY_FILES, Core::Check::GEMFILE_LOCK, Core::Check::HELPER_FILES, Core::Check::INITIALIZER_FILES, Core::Check::MAILER_FILES, Core::Check::MIGRATION_FILES, Core::Check::MODEL_FILES, Core::Check::PARTIAL_VIEW_FILES, Core::Check::ROUTE_FILES, Core::Check::SCHEMA_FILE, Core::Check::SKIP_FILES, Core::Check::VIEW_FILES
Instance Method Summary collapse
-
#initialize(options = {}) ⇒ MoveModelLogicIntoModelReview
constructor
A new instance of MoveModelLogicIntoModelReview.
Methods inherited from Review
#model_associations, #model_attributes, #models, #remember_variable_use_count, #reset_variable_use_count, #variable, #variable_use_count
Methods inherited from Core::Check
#add_error, debug, debug?, #errors, #is_ignored?, #is_interesting_file?, #method_missing, #parse_file?, #regex_ignored_files, #url, url
Constructor Details
#initialize(options = {}) ⇒ MoveModelLogicIntoModelReview
Returns a new instance of MoveModelLogicIntoModelReview.
21 22 23 24 |
# File 'lib/rails_best_practices/reviews/move_model_logic_into_model_review.rb', line 21 def initialize( = {}) super() @use_count = ['use_count'] || 4 end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class RailsBestPractices::Core::Check