Class: RailsBestPractices::Reviews::ReplaceComplexCreationWithFactoryMethodReview
- Inherits:
-
Review
- Object
- CodeAnalyzer::Checker
- Core::Check
- Review
- RailsBestPractices::Reviews::ReplaceComplexCreationWithFactoryMethodReview
- Defined in:
- lib/rails_best_practices/reviews/replace_complex_creation_with_factory_method_review.rb
Overview
Review a controller file to make sure that complex model creation should not exist in controller, should be replaced with factory method.
See the best practice details here rails-bestpractices.com/posts/2010/07/21/replace-complex-creation-with-factory-method/
Implementation:
Review process:
check all method defines in the controller files,
if there are multiple attribute assignments apply to one receiver,
and the receiver is a variable,
and after them there is a call node with message "save" or "save!",
then these attribute assignments are complex creation, should be replaced with factory method.
Constant Summary
Constants inherited from Core::Check
Core::Check::ALL_FILES, Core::Check::CAPFILE, Core::Check::CONFIG_FILES, Core::Check::CONTROLLER_FILES, Core::Check::DEPLOY_FILES, Core::Check::GEMFILE_LOCK, Core::Check::HELPER_FILES, Core::Check::INITIALIZER_FILES, Core::Check::MAILER_FILES, Core::Check::MIGRATION_FILES, Core::Check::MODEL_FILES, Core::Check::PARTIAL_VIEW_FILES, Core::Check::ROUTE_FILES, Core::Check::SCHEMA_FILE, Core::Check::SKIP_FILES, Core::Check::VIEW_FILES
Instance Method Summary collapse
-
#initialize(options = {}) ⇒ ReplaceComplexCreationWithFactoryMethodReview
constructor
A new instance of ReplaceComplexCreationWithFactoryMethodReview.
Methods inherited from Review
#model_associations, #model_attributes, #models, #remember_variable_use_count, #reset_variable_use_count, #variable, #variable_use_count
Methods inherited from Core::Check
#add_error, debug, debug?, #errors, #is_ignored?, #is_interesting_file?, #method_missing, #parse_file?, #regex_ignored_files, #url, url
Constructor Details
#initialize(options = {}) ⇒ ReplaceComplexCreationWithFactoryMethodReview
Returns a new instance of ReplaceComplexCreationWithFactoryMethodReview.
23 24 25 26 |
# File 'lib/rails_best_practices/reviews/replace_complex_creation_with_factory_method_review.rb', line 23 def initialize( = {}) super() @assigns_count = ['attribute_assignment_count'] || 2 end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class RailsBestPractices::Core::Check